# TODO thoughts.

- multiple insert, for many rows at one time.
  possibly like the regular insert, but does NOT execute until all rows done,
  and keeps appending values?
- geti(), memory efficient get()? (iterator)
